==> haskell-cheapskate-0.1.1.2-638-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-IorvtSlKA3nCK4mBbDSXyU
key:                  cheapskate-0.1.1.2-IorvtSlKA3nCK4mBbDSXyU
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  8cb01015cca668ea4c3fc7d4338ca1c3
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-IorvtSlKA3nCK4mBbDSXyU
depends:
    base-4.16.4.0 blaze-html-0.9.1.2-6wRAerZ4BzkA8WiagtXagU
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    deepseq-1.4.6.1 mtl-2.2.2 syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l
    text-1.2.5.0 uniplate-1.6.13-3kspk5MenPh76qCYq10Rz1
    xss-sanitize-0.3.7.2-FvrnD9Ma51519dBa7eyR78

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-730.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-3LYGuJNtlPgEWD00MwORTH
key:                  cheapskate-0.1.1.2-3LYGuJNtlPgEWD00MwORTH
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  295634c9e425438ae9b4aa7cc52d6084
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-3LYGuJNtlPgEWD00MwORTH
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-LTgARzkQmuR7wd3WENC7Bl
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv
    text-2.0.2 uniplate-1.6.13-FPxTMXtfUHnEXogiyqcBmu
    xss-sanitize-0.3.7.2-9O4isfx0wTUGoZgudSIti1

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
